<?php

namespace Litecms\Testimonial\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Testimonial\Interfaces\TestimonialsRepositoryInterface;
use Litecms\Testimonial\Repositories\Eloquent\Filters\TestimonialsPublicFilter;
use Litecms\Testimonial\Repositories\Eloquent\Presenters\TestimonialsListPresenter;

class TestimonialsPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        TestimonialsRepositoryInterface $testimonials
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.testimonial.modules'), 'testimonials', guard_url('testimonials'));
        $this->repository = $testimonials;
    }

    /**
     * Show testimonials's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(TestimonialsPublicFilter::class)
            ->setPresenter(TestimonialsListPresenter::class)
            ->select('testimonials.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('testimonial::testimonials.names'))
            ->view('testimonial::public.testimonials.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show testimonials.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('testimonial::testimonials.name'))
            ->view('testimonial::public.testimonials.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
